#[non_exhaustive]pub enum CoreError {
Io(Error),
NoSuchChannel(String),
}Expand description
Top level failure cases for rust-releases-core
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io(Error)
Returned in case of an i/o error
NoSuchChannel(String)
Returned in the event that the parsing a release channel with a given identifier does not exist