pub struct RustChangelog { /* private fields */ }Expand description
A Source which obtains release data from the official Rust changelog.
Implementations
Sourceimpl RustChangelog
impl RustChangelog
Sourcepub fn fetch_channel(
channel: Channel,
) -> Result<RustChangelog, RustChangelogError>
pub fn fetch_channel( channel: Channel, ) -> Result<RustChangelog, RustChangelogError>
Fetch all known releases from the official rust changelog